
/* layout for the content area in the preview screen */
div.preview {
  margin: -1px 0 0 0;
  padding: 0.3em 1em 1em 1em;
  border: 1px solid #789;
  background-color: #e3ecf7;
}

div.public {
  margin: 12px 16px 10px 16px;
  padding: 0.3em 1em 0.7em;
  border: 1px solid #789;
  background-color: #e3ecf7;
  width: 45em;
}

/* ________________________________________________________ alignments _____ */

div.public .image-left {
  text-align: left;
}
div.public .align-center,
div.public .image-center {
  text-align: center;
}
div.public .align-right,
div.public .image-right {
  text-align: right;
}
div.public .float-left {
  float: left;
  margin-right: 1em;
  clear: none;
}
div.public .float-right {
  float: right;
  margin-left: 1em;
  clear: none;
}


/* _________________________________________________________ typography _____ */

div.public h1,
div.public h2,
div.public h3,
div.public h4,
div.public h5,
div.public h6 {
  margin: 1em 0 0 0;
  color: #455885;
}
div.public h2 {
  margin-top: 0.8em;
  margin-bottom: 0.7em;
  font-size: 170%;
}
div.public h3 {
  margin-bottom: 0.6em;
  font-size: 145%;
}
div.public h4 {
  margin-bottom: 0.5em;
  font-size: 120%;
}
div.public h5 {
  margin-bottom: 0.2em;
  font-size: 110%;
}
div.public h6 {
  margin-bottom: 0.1em;
  color: #454545;
  font-size: 105%;
}
div.public h6.minor,
div.public h6.sub /* in kupu*/ {
  color: #676767;
  font-size: 100%;
}
div.public .subhead {
  color: #333767;
  font-weight: bold;
  font-family: verdana, arial, helvetica, sans-serif;
  line-height: 1.6em;
}
div.public p {
  margin: 0.5em 0em;
}
div.public ul {
  margin: 0.5em 0em;
  /* override default indent */
  padding-left: 1.4em;
}
div.public ol {
  margin: 0.5em 0em;
  /* override default indent */
  padding-left: 1.9em;
}
div.public dt {
  background: transparent;
  font-weight: bold;
}
div.public dd {
  background: transparent;
  margin-left: 1.5em;
}
div.public pre {
  padding: 0;
  border: none;
  color: #444466;
  background-color: transparent;
  font-size: 120%;
}
div.public sup {
  vertical-align:text-top;
}
div.public sub {
  vertical-align:text-bottom;
}


/* __________________________________________ silva specific typography _____ */

div.public p.lead {
  font-weight: bold;
}
div.public p.annotation {
  font-style: italic;
}
div.public div.citation {
  margin: 1em 3em;
  padding: 0.4em 2em 1.2em 2em;
  border: 1px solid #426061;
  color: #426061;
  background-color: #f4f3db;
  font-size: 110%;
}
div.public div.citation p {
  margin: 0.5em 0em;
}
div.public div.citation p.author {
  margin-bottom: 0;
  font-size: 90%;
  font-weight: bold;
}
div.public div.citation p.source {
  margin-top: 0;
  margin-bottom: 0;
  font-size: 90%;
}
div.public span.underline {
  text-decoration: underline;
}


/* __________________________________________________ silva list styles _____ */

div.public ul.disc {
  list-style-type: disc;
}
div.public ul.square {
  list-style-type: square;
}
div.public ul.circle {
  list-style-type: circle;
}
div.public ul.nobullet {
  list-style-type: none;
}
div.public ol.decimal {
  list-style-type: decimal;
}
div.public ol.upper-roman {
  list-style-type: upper-roman;
}
div.public ol.lower-roman {
  list-style-type: lower-roman;
}
div.public ol.upper-alpha {
  list-style-type: upper-alpha;
}
div.public ol.lower-alpha {
  list-style-type: lower-alpha;
}
div.public ul.toc-list {
  margin:0;
  line-height:130%;
}
div.public dl {
margin:0.5em 0;
}

/* ______________________________________________________________ links _____ */

/* highlighting index links */
/* keep this if you markup text with index elements, this overrides the
   highlighting in the editor */
div.public a.index-element {
  background-color: transparent;
  text-decoration: none;
}
div.public a:link {
  color: #0000aa;
  text-decoration: underline;
}
div.public a:visited {
  color: #4a00b2;
  text-decoration: underline;
}
div.public a:active {
  color: #3399cc;
}
div.public a:hover {
  color: #0000ff;
  text-decoration: none;
}
div.public a img {
  border: 0;
}

/* _________________________________________________ silva table styles _____ */

div.public table.silvatable {
  empty-cells: show;
  border-collapse: collapse;
  margin-bottom: 1em;
  font-size: 100%; /* FF needs this with SL */
  border-collapse:collapse;
  border-spacing:0;
}
div.public table.silvatable tr {
  vertical-align: top;
}
div.public table.silvatable tr.rowheading {
  font-weight: bold;
}
div.public table.silvatable th.align-left,
div.public table.silvatable td.align-left {
  text-align: left;
}

div.public table.silvatable th.align-center,
div.public table.silvatable td.align-center,
div.public table.silvatable th.align-center p,
div.public table.silvatable td.align-center p {
  text-align: center;
}
div.public table.silvatable th.align-right,
div.public table.silvatable td.align-right,
div.public table.silvatable th.align-right p,
div.public table.silvatable td.align-right p {
  text-align: right;
}
div.public table.datagrid,
div.public table.plain,
div.public table.list,
div.public table.grid {
  width: 100%;
}
div.public table.plain {
  border: none;
}
div.public table.list th {
  border: 2px solid #444444;
  border-style: solid none;
}
div.public table.list td {
  border: 1px solid #444444;
  border-style: solid none;
}
div.public table.grid th,
div.public table.grid td {
  border: 1px solid #444444;
}

div.public table.datagrid th,
div.public table.datagrid td {
  border: 2px solid #444444;
}
div.public table.simple {
  border-style: none;
}
div.public table.simple thead th {
  text-align: left;
  font-weight: normal;
}

/* _____________________________________________________ CSS2 selectors _____ */

div.public acronym[title],
div.public abbr[title] {
  cursor:help;
}
div.public h2 + h3 {
  margin-top: 0;
}
div.public h3 + h4 {
  margin-top: 0;
}
div.public h4 + h5 {
  margin-top: 0;
}
div.public h5 + h6 {
  margin-top: 0;
}
div.public h5 + p {
  margin-top: 0.3em;
}
div.public h6 + p,
div.public h6.minor + p {
  margin-top: 0;
}

/* end cascade */
