
/* _________________________________________________________ matrix nav _____ */

div.tabs a {
  background-color: #638776;
}

div.tabs a:visited {
  color:  #d9f3e2;
  background-color: #638776;
}

div.tabs a.selected {
  border-bottom-color: #b3d4bf;
  background-color: #b3d4bf;
}

div.tabs a.selected:visited {
  border-bottom-color: #b3d4bf;
  color: #444;
  background-color: #b3d4bf;
}

div.tabs a:hover {
  border-bottom-color: #b3d4bf;
  color: #444;
  background-color: #b3d4bf;
}

div.tabs a.left:hover {
  border-bottom-color: #b3d4bf;
}

div.tabs a.right:hover {
  border-bottom-color: #b3d4bf;
}

div.tabs a.recede {
  border-bottom: 1px #8b939b solid;
  color: #444;
  background-color: #8fb39e;
}

div.tabs a.recede:hover {
  border-bottom-color: #b3d4bf;
  background-color: #b3d4bf;
}

div.tabs a.normal:visited {
  background-color: transparent;
}

div.tabs a.transportlet:link {
  color:  #d9f3e2;
  background-color: #638776;
}
div.tabs a.transportlet:visited {
  color:  #d9f3e2;
  background-color: #638776;
}
div.tabs a.transportlet:hover {
  border-bottom-color: #b3d4bf;
  color: #444;
  background-color: #b3d4bf;
  text-decoration: none;
}

/* ___________________________________________________________ flow bar _____ */

div.flowbar {
  border-top: 3px solid #b3d4bf;
}


/* _______________________________________________________ middleground _____ */

div.middleground {
  background-color: #779D8A;
}

div.middleground a.selected {
  /* The selected tab. There's only one  */
  color: #444;
  background-color: #a7d4b6;
}

div.middleground a.selected:visited {
  color: #444;
  background-color: #a7d4b6;
}


/* ______________________________________________________ sidebar stack _____ */

td.selected {
  background: #ddece6;
}

td.unselected {
  border-top-color: #c0d5ce;
  border-bottom-color: #c0d5ce;
  background: #c0d5ce;
}

td.unselected:hover {
  background-color: #d4e9e7;
}


/* ______________________________________________ content listing table _____ */

table.listing td.top h2 {
  color: #c5d4ca;
}

table.listing tr.top-controls h3 {
  color: #ddeee3;
}

/* _____________________________________________________________ footer _____ */

div.footer {
  background-color: #c5d4ca;
}


/* _______________________________________________________________ misc _____ */

a.index-element {
  background-color:#efe4ad ! important;
}

