/* --- reset css --- */
body,div,dl,dt,dd,ul,ol,li,h1,h2,h3,h4,h5,h6,pre,code,form,fieldset,legend,input,textarea,p,blockquote,th,td{margin:0;padding:0;}table{border-collapse:collapse;border-spacing:0;}fieldset,img{border:0;}address,caption,cite,code,dfn,em,strong,th,var{font-style:normal;font-weight:normal;}li{list-style:none;}caption,th{text-align:left;}h1,h2,h3,h4,h5,h6{font-size:100%;font-weight:normal;}q:before,q:after{content:'';}abbr,acronym{border:0;font-variant:normal;}sup{vertical-align:text-top;}sub{vertical-align:text-bottom;}input,textarea,select{font-family:inherit;font-size:inherit;font-weight:inherit;}input,textarea,select{font-size:100%;}legend{color:#000;}del,ins{text-decoration:none;}

body {
  color: red;
  font: 70% Verdana, Arial, Helvetica, sans-serif;
  background-color: #9ab;
}

p { color: #2D374C;}

/* _________________________________________________________ sectors _______ */

div.workspace, div#footerarea { background: #dde5ee;}

/* ____________________________________ path bar _______ */

div.pathbar {
  padding: 0 4px 0.2em 22px;
  color: #51585c;
  background: #b0c4d8 url(skylight.gif) repeat-x;
  font-size: 90%;
  line-height: 1.4em;
}

div.pathbar a {
  color: #373e42;
  font-weight: normal;
}
div.pathbar a:visited { color: #373e42;}
div.pathbar a:hover {
  color: #60686b;
  text-decoration: underline;
}

div.pathbar a.manage {
  margin-left: 0.5em !important;
  color: #757c7f;
}

div.pathbar a.idea { color: #c2c5c7;}
div.pathbar a.idea:visited {
  color: #c2c5c7;
}
div.pathbar a.idea:hover {
  color: #eaf3f5;
  text-decoration: none;
}

div.pathbar img {
  margin: 0 0 0 -22px;
  vertical-align: top;
}

/* __________________________________ matrix nav _______ */
div.tabs {
  display: block;
  height: 1.2em;
  padding: 0 16px;
  border-width: 1px;
  border-style: none none solid none;
  border-bottom-color: #BCC2CA;
  background: #d7e8f0 url(skyrise.gif) repeat-x;
}

/* The normal, unselected tabs. They are all links */
div.tabs a {
  float: left;
  display: block;
  width: 7.5em;
  height: 1.1em;
  border: 1px solid #3d4b67;
  border-bottom-color: #757c7f;
  color: #e3ecff;
  background: #61738A url(reflection.png) repeat-x top left;
  text-align: center;
  font-weight: normal;
}

div.tabs a:visited {
  color: #e3ecff;
  background-color: #61738A;
}

div.tabs a:hover {
  border-bottom-color: #c1daf3;
  color: #444;
  background-color: #c1daf3;
  text-decoration: none;
}

/* The selected tab. There's only one of these */
div.tabs a.selected {
  border-bottom-color: #c1daf3;
  color: #444;
  background-color: #c1daf3;
}

div.tabs a.selected:visited {
  border-bottom-color: #c1daf3;
  color: #444;
  background-color: #c1daf3;
}

/* The parent tab of a subscreen. There might be one of these. */
div.tabs a.recede {
  border-bottom-color: #61738A;
  color: #444;
  background-color: #9ebad7;
}

div.tabs a.recede:hover {
  border-bottom-color: #c1daf3;
  background-color: #c1daf3;
}

/* The left side of the tab. */
div.tabs a.left {
  width: 1.5em;
  border-style: solid none solid solid;
}

div.tabs a.left:hover { border-bottom-color: #c1daf3;}

/* The right side of the tab. */
div.tabs a.right {
  width: 1.5em;
  border-style: solid solid solid none;
}

div.tabs a.right:hover { border-bottom-color: #c1daf3;}

div.tabs img {
  margin: 0.3em 0 0;
  border: none;
  vertical-align: bottom;
}

div.tabs div.air {
  display: block;
  float: left;
  width: 1.6em;
  height: 1em;
  background-color: transparent;
}

/* view public page button */
div.tabs a.transportlet {
  width: auto;
  padding-right: 1em;
  padding-left: 1.5em;
}

/* help (available as accesskey link) */
div.tabs a.normal {
  float: right;
  width: auto;
  height: auto;
  border: none;
  background: transparent;
}

/* ____________________________________ flow bar _______ */
div.flowbar {
  border-top: 3px solid #c1daf3;
  border-bottom: 1px solid #6E8094;
  background-color: #c1daf3;
  clear: both;
}

/* ________________________________ middleground _______ */
div.middleground {
  border-bottom: 1px solid #657;
  background: #8797ab url(reflection.png) repeat-x top left;
  height: 16px;
  padding: 0 6px;
}

div.middleground form.middleground-form { display: inline;}

/* The normal, unselected buttons. They are all links */
div.middleground a, div.middleground input[type="submit"] {
  height: 16px;
  display: inline-block;
  margin: 0 1px;
  padding: 0 0.5em;
  border: 1px solid #345;
  border-style: none solid none;
  background: url(reflection.png) repeat-x top left;
  font-weight: normal;
}

div.middleground a {
  display: block;
  float: left;
}

a.popup-button {
  margin: 0 1px;
  padding: 0 5px 2px;
  border: none;
  color: #d9f3da;
  background: #064C29 url(reflection.png) top left repeat-x;
  cursor: pointer;
  line-height: 16px;
  display:inline-block;
}

a.popup-button:link, div.middleground a:link {
  color: #d9f3f1;
  background-color: #336;
  text-decoration: none;
}
a.popup-button:visited, div.middleground a:visited {
  color: #d9f3f1;
  background-color: #4d5680;
}
a.popup-button:hover, div.middleground a:hover {
  border-color: #567;
  color: #e5fffe;
  background-color: #74748b;
  text-decoration: none;
}
a.popup-button:active, div.middleground a:active {
  border-color: #789;
  color: #b3fffb;
  background-color: #8d97c2;
}

/* A selected, highlighted button. There should only be one of these. */
div.middleground a.selected {
  color: #424244;
  background-color: #b6d6f3;
}

/* _______ middleground transporter (movement buttons) _______ */
div.middleground div.transporter {
  float: left;
}

/* _______ middleground executor (action buttons) _______ */

div.middleground div.executor {
  float: right;
}

div.middleground div.executor select {
  float: left;
  height: 16px;
}

/* --- valid css hack for ie6 and ie7 that require fixed width on select */
*:first-child+html div.middleground div.executor select,
* html div.middleground div.executor select {
  width: 130px;
  float: right;
}

div.middleground div.executor a, div.middleground div.executor input[type="submit"] {
  color: #b3fffb;
  background-color: #1f626d;
}
div.middleground div.executor a:hover, div.middleground div.executor input[type="submit"]:hover {
  color: #e5ffec;
  background-color: #538da3;
}
div.middleground div.executor a:active, div.middleground div.executor input[type="submit"]:active {
  color: #bfffd3;
  background-color: #64ABC8;
}

/* --- valid css hack for ie6 and ie7 that require no border */
*:first-child+html div.middleground div.executor input[type="submit"],
* html div.middleground div.executor input[type="submit"] {
  border: none;
}

/* ______________________________________ footer _______ */
div.footer {
  clear: both;
  margin: 0.5em 0 0;
  padding: 0 16px 0.1em;
  border-top: #909699 1px solid;
  border-bottom: none;
  color: #42484c;
  background-color:#c4d6e7;
  font-size: 94%;
}

div.footer a {
  color: #000;
  font-weight: normal;
  text-decoration: none;
}
div.footer a:visited { color: #000;}

/* ________________________________ personal bar _______ */
div.personalbar {
  padding: 0.1em 16px 0.2em 16px;
  border-bottom: #42484c 1px solid;
  background-color: #4c5c6c;
  text-align: center;
}

div.personalbar a {
  color: #b7cee6;
  text-decoration: none;
}
div.personalbar a:visited { color: #b7cee6;}

div.personalbar img { vertical-align: middle;}

/* _______________________________ columns table _______ */

table th, table td { vertical-align: top;}

table.columns { width: 100%;}

/* 3 column table (default) */
table.columns td.left {
  width: 20%;
  padding: 0 8px 0 8px;
}
table.columns td.main {
  width: 60%;
  padding: 0 7px 0 0;
}
table.columns td.right {
  width: 20%;
  padding: 0 8px 0 0;
}

/* 2 column table */
table.columns2 td.left {
  width: 20%;
  padding: 0 0 0 7px;
}
table.columns2 td.main {
  width: 80%;
  padding: 0 7px 0 8px;
}

/* 1 column */
table.columns1 td.main {
  width: 100%;
  padding: 0 7px 0 7px;
}

/* _______________________________ listing table _______ */

table.listing {
  width: 100%;
  margin: 0 0 1em 0;
  border: 1px solid #789;
  border-style: solid none solid solid;
  color: #444;
  font-family:"Lucida Grande", "Lucida Sans Unicode", verdana, arial, helvetica, sans-serif;
}

table.listing img { vertical-align: middle;}

/* ______________ rows ______________ */

table.listing td.top {
  padding: 0;
  color: #c5d4ca;
  background-color: #456;
}

table.listing tr.top-controls td {
  padding: 0 0.3em 0.2em;
  background-color: #567;
}

table.listing tr.inter-controls td {
  padding: 0 0.2em;
  color: #c9dfe2;
  background-color: #728394;
}

table.listing tr.controls td {
  padding: 0 0.2em;
  border-top: 1px solid #789;
  color: #c9dfe2;
  background-color: #789;
}

/* cycle text color in listing rows */
table.listing tr.odd {
  background-color: #d7e4f0;
}
table.listing tr.even td { background: #cfdbe7;}

table.listing tr.odd:hover td, table.listing tr.even:hover td {
  background-color: #e5f2ff;
}

tr.divider td, td.divider {
  height: 0.5em;
  background-color: #89a; /* dark */
}

tr.separator td, td.separator {
  height: 0.5em;
  background-color: #c5d6e6; /* light */
}

/* ______________ cells ______________ */
table.listing th {
  padding:0 0.3em;
  border-top: none;
  border-bottom: 1px solid #789;
  border-right: 1px solid #789;
  color: #e0eefc;
  background-color: #678;
  vertical-align: middle;
  white-space: nowrap;
}

table.listing th.listing-left {
  width: 2%;
  padding-left: 0.2em;
  text-align: left;
}

table.listing th.listing-right {
  width:7%;
  text-align: right;
}

table.listing th.align-left, table.listing td.align-left {
  text-align: left;
}
table.listing th.align-center, table.listing td.align-center {
  text-align: center;
}
table.listing th.align-right, table.listing td.align-right {
  text-align: right;
}

table.listing td {
  padding: 0 0.3em;
  border-left: 1px solid #789;
  border-right: 1px solid #789;
}

/* title cell */
table.listing td.top h2 {
  margin: 0 0.1em 0.1em;
  color: #c5d4ca;
}
table.listing td.top img {
  vertical-align: top;
}

/* _______ subhead cells _______ */
table.listing tr.top-controls h3 {
  margin: 0 0 0.1em;
  padding: 0;
  color: #ddeee3;
  line-height: 100%;
}

table.listing tr.inter-controls h3 {
  margin:0 0.3em 0.1em;
  color: #dbe9f7;
}

/* _______ flanking cells _______ */
table.listing td.listing-left {
  padding: 0 0.3em 0 0.2em;
  white-space: nowrap;
}

table.listing td.listing-right {
  padding: 0 0 0 0.2em;
  white-space: nowrap;
}

/*
* some usability selectors:
* create a displayed block of the links, because then you can click on
* the whole tablecell and don't have to focus the text
*/
table.listing tbody a {
  display: block;
}
/* make inline in designation descriptions, new screen headings, and
   optionally in tbody, row with unblock class */
table.listing tbody p a, table.listing tbody div.subhead a,
table.listing tbody.unblock a, table.listing tr.unblock a {
  display: inline;
}

table.listing a.icon img {
  display: inline;
  float: left;
  margin-right: 0.3em;
}

/* __________________________ sidebar navigation _______ */
table.listing th.top {
  padding: 0;
  border: 1px solid #789;
  border-bottom: none;
  color: #e3eef0;
  background-color: #678;
  text-align: center;
}

table.listing th.top img {
  vertical-align: bottom;
  padding: 0;
}

table.listing th.top a.normal:link {
  display: block;
  color: #e3ecff;
  background-color: #678;
}

table.listing th.top a.normal:visited {
  display: block;
  color: #e3ecff;
  background-color: #678;
}

table.listing th.top a.normal:hover {
  display: block;
  color: #444;
  background-color: #d2e6f8;
  text-decoration: none;
}

table.listing th.subth {
  color: #e9f5f7;
  background-color: #89a;
  text-align: center;
}

/* _______ uplinks _______ */
table.listing a.top {
  display: block;
  float: left;
  width: 1.4em;
  padding: 0.4em 0.2em 0;
  border-right: 1px solid #789;
  background-color: #678;
}

table.listing a.up {
  display: block;
  float: right;
  width: 1.4em;
  padding: 0.4em 0.2em 0;
  border-left: 1px solid #789;
  background-color: #678;
}

table.listing a.top:hover {
  padding: 0 0.2em 0;
  border-style: solid solid none none;
  color: #c1daf3;
  background-color: #c1daf3;
  text-decoration: none;
}

table.listing a.up:hover {
  padding: 0 0.2em 0;
  border-style: solid none none solid;
  color: #c1daf3;
  background-color: #c1daf3;
  text-decoration: none;
}

td.selected {
  padding-left: 0 ! important;
  padding-right: 0 ! important;
  border-top: 1px solid #789;
  border-bottom: 1px solid #789;
  background-color: #dae7fa;
}

td.unselected {
  padding-left: 0 ! important;
  padding-right: 0 ! important;
  border-top: 1px solid #c6d2dd;
  /* wim: made it look like nav had no border. border-bottom:  1px solid #c6d2dd; */
  background-color: #c6d2dd;
}

td.unselected:hover {
  color: #444;
  background-color: #d5e1ef;
  cursor: pointer;
}

table.listing td a.normal:link {
  display: block;
  color: #e3ecff;
  background-color: #678;
}

table.listing th.top a.normal:visited {
  display: block;
  color: #e3ecff;
  background-color: #678;
}

table.listing th.top a.normal:hover {
  display: block;
  color: #444;
  background-color: #d2e6f8;
  text-decoration: none;
}

/* _______ slidelinks _______ */
table.listing a.left {
  display: block;
  float: left;
  width: 8px;
  height: 16px;
}

table.listing a.right {
  display: block;
  float: right;
  width: 8px;
  height: 16px;
}

table.listing a.navicon {
  display: block;
  float: left;
  width: 19px;
  height: 100%;
}

table.listing a.left:hover {
  background-image: url(slideleft.gif);
  background-color: transparent;
  text-decoration: none;
}

table.listing a.right:hover {
  background-image: url(slideright.gif);
  background-color: transparent;
  text-decoration: none;
}

div.normal { display: block;}

/* ________________________________ focus shapes _______ */
form.sublisting { padding-top: 1em;}

/* ________________________________________________ form definitions _______ */
input {
  margin: 1px 0;
  padding: 1px 2px;
  border: 1px solid #366;
  color: #336;
  background-color: #d5e7e7;
  font: normal 100% verdana, helvetica, arial, sans-serif;
}

textarea {
  margin: 1px 0;
  padding: 1px 2px;
  border: 1px solid #366;
  color: #336;
  background-color: #d5e7e7;
  font: normal 100% verdana, helvetica, arial, sans-serif;
}

input.store, textarea.store, input.field, textarea.field {
  width: 99%;
}

/* valid ie6 and ie7 hack */
*:first-child+html input.store, *:first-child+html input.field,
* html input.store, * html input.field,
*:first-child+html textarea.store, *:first-child+html textarea.field,
* html textarea.store, * html textarea.field {
  width: 97%;
}

select {
  margin: 0 1px;
  border: 1px solid #366;
  color: #444;
  background-color: #d5e7e7;
  font: normal 100% verdana, helvetica, arial, sans-serif;
  font-size: 95%;
  vertical-align: top;
}

select.manipulator {
  border: 1px solid #6bb591;
  border-color: #064C29 #345 #064C29;
  color: #d9f3da;
  background-color:#195A3E;
}

td.element select.field,
select.store {
  width:100%;
}

/* ie7 valid css hack */
*:first-child+html select.store,
*:first-child+html select.field {
  width:98%;
}

select.transporter {
  border: 1px solid #8faecf;
  border-color: #283365 #345 #283365;
  color: #d9f3f1;
  background-color: #283365;
}

input[type="submit"] {
  overflow: visible;
  cursor: pointer;
}

/* zeam form action align */
input.action {
  float: right;
}

div.multi-actions {
  margin: 0.5em 0 0 1.7em;
}
div.multi-actions input {
  text-transform: lowercase;
}
input[type="checkbox"] + input[type="hidden"] + input.field-textline {
  width: 94%; /* shortens field-textline when in a multi-actioned field */
}

form.zeam-form div.field-collection-line {
  padding: 10px 0px;
  border-bottom: 1px solid #555;
}

form.zeam-form div.field-collection div.multi-actions {
  margin: 0px;
  padding: 5px 0px;
}

form.zeam-form div.field-collection span.field-error {
  color: #cc0000;
  background: transparent;
}


/* manipulator button style from which all others derive */
input.button, input.action, input.canceler, button.button, input.manipulator {
  margin: 0 1px;
  padding: 0 5px 2px;
  border: none;
  color: #d9f3da;
  background: #064C29 url(reflection.png) top left repeat-x;
  cursor: pointer;
}

/* used in conflict situations where public view css would win */
button.button {
  font: normal 100% verdana, helvetica, arial, sans-serif;
}

input.transporter, button.transporter {
  color: #d9f3f1;
  background-color: #283365;
}

input.executor, button.executor {
  color: #b3fffb;
  background-color: #1f626d;
}

input.remover, input.warning, button.remover, button.warning {
  color: #fdeaea;
  background-color: #752e2f;
}

input.canceler, button.canceler {
  color: #ccd7d6;
  background-color: #444446;
  float: left;
}

/* _______ state coded publishing action buttons _______ */
input.rejector { background-color: #8f7f01;}
input.revoker { background-color: #008c55;}
input.closer { background-color: #202080;}

/* _______ form labels _______ */

label { color: #403f80;}

tr.controls label, tr.inter-controls label { color: #e0eefc;}

th label { color: #e0eefc;}

/* _______ field iterators _______ */

table.listing td.designator {
  padding-top:0.1em;
  padding-bottom:0.1em;
}
table.listing td.designator label { font-size: 115%;}
table.listing td.designator span.matchlabel { font-size: 115%;}
table.listing td.designator p, td.designator ul,
table.listing td.element p,
table.listing td.field p {
  margin:0;
  color:#667;
}
table.listing tr:hover td.designator p,
table.listing tr:hover td.designator ul:hover,
table.listing tr:hover td.element p,
table.listing tr:hover td.field p {
  color:#333;
}
table.listing td.element,
table.listing td.field {
  padding-top:0.1em;
  padding-right:0.4em;
}

/* _______ pseudo form button selectors, matches transporter button style _______ */

/* transport between screens */
a.transporter {
  margin: 0;
  padding: 0.1em 0.7em 0.2em;
  border: 1px solid #345;
  border-style: none solid none;
  background-image: url(reflection.png);
  background-position: top left;
  background-repeat: repeat-x;
  font: normal 100% verdana, helvetica, arial, sans-serif;
  font-size: 100%;
}
a.transporter:link {
  color: #d9f3f1;
  background-color: #283365;
}
a.transporter:visited {
  color: #d9f3f1;
  background-color: #283365;
}
a.transporter:hover {
  border-color: #99b4cf;
  color: #e5fffe;
  background-color: #74748b;
  text-decoration: none;
}
a.transporter:active {
  color: #bfffd3;
  background-color: #008a8a;
}

/* _______ subscreen parent links _______ */

table.listing td.parent {
  padding: 0;
  border: 1px solid #789;
  background-color: #283365;
  text-align: center;
  vertical-align: bottom;
}

table.listing td.parent a {
  color: #d9f3f1;
  text-decoration: none;
}
table.listing td.parent a:hover {
  color: #bfffd3;
  background-color: #53538b;
}
/* only used in lookup ui for back */
table.listing div.transport-border {
  padding-bottom: 1px;
  border: 1px solid #8faecf;
}
table.listing div.transport-border:hover {
  color: #bfffd3;
  background-color: #53538b;
}

/* _____________________________ form control interaction _______ */

/* _______ field interaction _______ */
/* these selectors are also define unclassed submit buttons */

input:hover, textarea:hover, select:hover {
  border-color : #599;
  color:#339;
  background-color: #def2f2;
}

input:focus, textarea:focus, select:focus {
  border-color : #0ff;
  color:#339;
  background-color: #edf7f7;
}

input:focus:hover, textarea:focus:hover {
  background-color: #f2fcfc;
}

select:focus, select:hover { color:#336;}

/* _______ controls candy: hover/focus _______ */

/* manipulator warm glow */
input.action:hover, input.button:hover, button.button:hover, input.manipulator:hover {
  border-color: #567;
  color: #e5fffe;
  background-color: #4a7f67;
}
input.button:focus, button.button:focus, input.manipulator:focus {
  border-color: #789;
  color: #bfffd3;
  background-color: #62A269;
}

/* transporter cool glow */
input.transporter:hover, button.transporter:hover {
  color: #e5fffe;
  background-color: #68687e;
}
input.transporter:focus {
  color: #b3fffb;
  background-color: #8d97c2;
}

/* executor eerie glow */
input.executor:hover {
  color: #e5ffec;
  background-color: #4c8298;
}
input.executor:focus {
  color: #bfffd3;
  background-color: #5B99B3;
}

/* remover hot glow */
input.remover:hover, input.warning:hover {
  color: #fff5f5;
  background-color: #a85353;
}
input.remover:focus, input.warning:focus {
  color: #f0c0c0;
  background-color: #53538b;
}

/* state coded button hovers */
input.rejector:hover {
  color: #e5ffec;
  background-color: #9b8800;
}
input.revoker:hover {
  color: #e5ffec;
  background-color: #009a62;
}
input.closer:hover {
  color: #e5ffec;
  background-color: #4a4aa7;
}

input[type="radio"] {
  margin: 0 0.5em 0;
  width: auto;
  border: none;
}
input[type="checkbox"] {
  margin: 0 0.4em 0 0;
  width: auto;
  border: none;
}

/* default stylers for classless buttons (either delete or make into shockers):*/

input[type="submit"]:hover, input[type="button"]:hover {
  color: #bfffd3;
  background-color: #69878c;
}
input[type="submit"]:focus, input[type="button"]:focus {
  color: #bfffd3;
  background-color: #008a8a;
}

/* for sub-fielded fields */
div.multi-field input.field-textline {
width: 94%;
}
div.multi-actions input[value="Add"] {
  color: #d9f3f1;
  background-color: #283365;
}
div.multi-actions input[value="Remove"] {
  color: #fdeaea;
  background-color: #752e2f;
}

table.listing td.element input[type="radio"] {
  margin: 0.2em 0.2em 0.2em 0;
}

/* ________________________________________________ info + clipboard _______ */
div.info {
  margin: -1px 0 1em 0;
  padding: 0.2em 0.4em 0.3em;
  border: 1px solid #789;
  color: #336;
  background-color: #c6d2dd;
}

div.info h3 {
  margin: 0.2em 0;
  color: #336;
}

div.info h3 img {
  vertical-align:top;
}

div.info h4 {
  margin:0.6em 0 0;
  font-size:100%;
}

div.info p {
  margin:0 0 0.3em;
}

div.info p img.icon {
  vertical-align:bottom;
}

div.info p span.orientation {
  display: block;
  margin-top: 0.3em;
  border: 1px dotted black;
  text-align: center;
}
div.info p span.portrait {
  width: 4.5em;
  height: 6em;
}
div.info p span.landscape {
  width: 6.5em;
  height: 3.5em;
}
div.info p span.square {
  width: 4em;
  height: 4em;
}

select.clipboard, select.clipboard:focus, select.clipboard:hover {
  width: 100%;
  max-width: 100%;
  margin-top: 0.1em;
  margin-bottom: -0.5em;
  border: 1px solid #909699;
  color: #373e42;;
  background: #cfdbe7;
  font-size: 90%;
  line-height: 96%;
}

select.clipboard option.disabled {
  color: #dbf3f6;
  background: #678;
}

/* references listing box */
div.info div.refitem img.icon {
  float: left;
}
div.info div.refitem p {
  margin-left: 20px;
  margin-right: 18px;
}


/* ________________________________________________________ feedback _______ */

/* feedback under the matrix nav */
div.fixed-feedback {
  border-bottom: 1px solid #789;
  padding:0 9px 0.1em 9px;
  color: #555;
  background-color: #f3f3d9;
  border-collapse: collapse;
}
div.fixed-alert {
  height: 1%; /*hack for ie */
  border-bottom: 1px solid #789;
  padding:0 9px 0.1em 9px;
  color: #3c2d50;
  background-color: #f7d1d1;
  border-collapse: collapse;
}
div.fixed-clear {
  padding:0 9px 0.1em 9px;
  border-bottom: 1px solid #dde5ee;
  background-color: transparent;
  border-collapse: collapse;
}
div.fixed-clear a.reveal {
  color: #eaf3f5;
}
div.fixed-clear a.reveal:visited {
  color: #eaf3f5;
}
div.fixed-clear a.reveal:hover {
  color: #8b9194;
  text-decoration: none;
}

/* for notifications in right column */
td.right div.feedback {
  margin-top: 0;
}

/* floating feedback  */
div.feedback {
  position:relative; /* for IE6 peekaboo bug */
  border: 1px solid #789;
  padding: 0.4em 0.7em 0.7em 0.7em;
  color: #555;
  background-color: #f3f3d9;
}
div.alert {
  border: 1px solid #789;
  padding: 0.4em 0.7em 0.7em 0.7em;
  color: #3c2d50;
  background-color: #f7d1d1;
}
div.feedback a {
  color: #000;
  text-decoration: underline;
}

/* table row/cell feedback  */
table.listing tr.feedback, table.listing td.feedback {
  padding-top: 0.1em;
  padding-bottom: 0.2em;
  border-top: 1px solid #789;
  color: #555;
  background-color: #f3f3d9;
}
table.listing tr.alert, table.listing td.alert {
  border-top: 1px solid #789;
  border-bottom: 1px solid #789;
  color: #3c2d50;
  background-color: #f7d1d1;
}


/* _______ message box in content publish screen _______ */
table.listing .message {
  padding: 0;
}

table.listing div.message {
  padding: 0.2em 0.6em 0.2em 0.6em;
  border: 1px solid #557;
  border-style: solid none solid none;
  color: #2e2e77;
  background-color: #d9f4eb;
  font-weight: normal;
}

/* ______________________________________________________ typography _______ */
h1, h2, h3, h4, h5, h6 {
  margin: 0 0 1em 0;
  padding: 0;
  border: none;
  font-weight: bold;
}

h1 { font-size: 140%;}

h2 {
  font-size: 125%;
  color:#455885;
}

h3 {
  font-size: 115%;
  color:#455885;
}

h4 { font-size: 110%;}

h5 { font-size: 105%;}

h6 { font-size: 100%;}

code { font-size: 140%;}

a {
  color: #000;
  background-color: transparent;
  text-decoration: none;
}

i, em { font-style:italic;}

/* ___________________________________________ Silva specific styles _______ */
img { border: none;}

img.icon { margin: 0;}

a.icon:hover { text-decoration: none;}

/* _________________________________ align/float _______ */
.image-left { text-align: left;}
.image-center { text-align: center;}
.image-right { text-align: right;}

.float-left {
  float: left;
  clear: none;
  margin-right: 1em;
}
.float-right {
  float: right;
  clear: none;
  margin-left: 1em;
}

/* _______________________________________ lists _______ */
dt { background: transparent;}

dd {
  background: transparent;
  margin-left: 2.5em;
}

ul {
  margin-top: 0.2em;
  padding-left: 1.4em;
  line-height: 130%;
}

ul.tips { list-style-type: square;}

/* ___________________________________________________________ links _______ */
a:link {
  color: #00a;
  text-decoration: none;
}
a:visited {
  color: #5900b2;
  text-decoration: none;
}
a:active { color: #39c;}
a:hover {
  color: #00a;
  text-decoration: underline;
}

/* blacklink selectors */
a.blacklink { line-height: 16px;}
a.blacklink:link {
  color: #333;
  text-decoration: none;
}
a.blacklink:visited {
  color: #333;
  text-decoration: none;
}
a.blacklink:hover {
  color: #333;
  text-decoration: underline;
}

/* underline (blue) selectors */
a.underline:link {
  color: #000080;
  text-decoration: underline;
}
a.underline:visited {
  color: #000080;
  text-decoration: underline;
}
a.underline:hover {
  color: #005050;
  text-decoration: none;
}

/* highlighting index links */
a.index-element {
  background-color: #e9ff97;
  text-decoration: none;
}

/* draft (red) selectors */
.draft, a.draft { color: #cc0000;}

/* pending (yellow) selectors */
.pending, a.pending { color: #8f7f01;}

/* approved (green) selectors */
.approved, a.approved { color: #007746;}

/* published (blue) selectors */
.published, a.published { color: #000080;}

/* closed (gray) selectors */
.closed, a.closed { color: #666;}

/* draft (red) selectors */
a.draft:link {
  color: #cc0000;
  text-decoration: none;
}
a.draft:visited {
  color: #cc0000;
  text-decoration: none;
}
a.draft:hover {
  color: #cc0000;
  text-decoration: underline;
}

/* pending (yellow) selectors */
a.pending:link {
  color: #8f7f01;
  text-decoration: none;
}
a.pending:visited {
  color: #8f7f01;
  text-decoration: none;
}
a.pending:hover {
  color: #8f7f01;
  text-decoration: underline;
}

/* approved (green) selectors */
a.approved:link {
  color: #007746;
  text-decoration: none;
}
a.approved:visited {
  color: #007746;
  text-decoration: none;
}
a.approved:hover {
  color: #007746;
  text-decoration: underline;
}

/* published (blue) selectors */
a.published:link {
  color: #000080;
  text-decoration: none;
}
a.published:visited {
  color: #000080;
  text-decoration: none;
}
a.published:hover {
  color: #000080;
  text-decoration: underline;
}

/* closed (gray) selectors */
a.closed:link {
  color: #666;
  text-decoration: none;
}
a.closed:visited {
  color: #666;
  text-decoration: none;
}
a.closed:hover {
  color: #666;
  text-decoration: underline;
}

/* ____________________________________________________ local styles _______ */
.hilite { background: #ebecef;}

/* form datetime field punctuation */
.punctuation {
  font-family: impact, verdana, arial, helvetica, sans-serif;
  font-size: 15px;
}

span.required {
  color: #cc0000;
  font-family: impact, verdana, arial, helvetica, sans-serif;
}

table.listing tr.controls td span.required {
  color: #c9dfe2;
}

.warning { color: #aa0000;}

.error {
  color: #cc0000;
  background: transparent;
}

.fault { color: #ff1111;}

.subhead {
  color: #333767;
  font-weight: bold;
  font-family: verdana, arial, helvetica, sans-serif;
}

.idea { color: #634d82;}

/* defines the width of the text in help, etc */
.readable {
  width: 512px;
  max-width: 40em;
  line-height: 1.3em;
}

/* definitions for batching */
div.listingbar {
  width: 60em;
  margin: 2em 0;
}

div.listingbar .next { margin-left: 5em;}

div.listingbar .previous { margin-right: 5em;}

/* styles for the elaborate code source */
.elaborate fieldset {
  float:left;
  margin-bottom:0.2em;
}

.elaborate input.button {
  float:left;
  clear:left;
  margin-left:0.2em;
  margin-bottom:0.3em;
}

/* styles for the dynamic reference lookup window (from
   kupustyles.css) so that this widget works outside of
   kupu */
button.kupu-button {
 height: 20px;
 padding: 0;
}

/* start reference lookup window styles */
.kupu-link-reference-table { width: 100%;}

.kupu-link-reference-table td { white-space: nowrap;}
.kupu-link-reference-table td.buttoncell {
 width: 21px;
 vertical-align: top;
 border-right: none;
 padding: 0;
}

.kupu-link-reference-table button.kupu-link-lookupbutton {
  background-image: url("system-search.png");
}
.kupu-link-reference-table button.kupu-link-editbutton {
  background-image: url("edit-find.png");
  display: none;
}

button.kupu-link-reference {
  width: 20px;
  margin-right: 1px;
  overflow: visible;
  background-color: transparent;
}
button.kupu-link-reference:hover { background-color: #b3d4bf;}
/* end reference lookup window styles */

/* for the calendar button */
button.calendar-button {
  background: url("calendar.gif") no-repeat 3px -1px;
  margin-top:2px;
  border:none;
}

.uptotop {
  float:left;
  clear:left;
  width:16px
}

.jumtotop {
  float:right;
  clear:right;
  text-align:right;
  width:16px
}

.idea-container {
  float: right;
  margin-right: 5px;
}

/* ______________________________________ Middlespace ____ */

.middlespace { padding:0 8px;}

/* ___ navigation ___ */

.navigation {
  width: 250px;
  float: left;
  margin: 0 10px 0 0;
}

/* ___ viewport ___ */

.viewport {
  margin: 0 10px 0 0;
  float: left;
  width: 720px;
}

.viewport-clear { clear: both;}

form.zeam-form span.footer-fields {
  line-height: 1.6em;
  float: right;
}

/* --- valid css hack for ie6 and ie7 that require fixed width on select */
*:first-child+html .zeam-form span.footer-fields select,
* html form.zeam-form span.footer-fields select {
  width: 130px;
  float: right;
}

form.zeam-form .footer-fields span.error {
  background-color: #f7d1d1;
  padding: 0.1em 0.5em;
  color: #a00;
}

.portlets {
  width: 250px;
  float: left;
}

/* jq ui widgets */

.ui-widget div.fixed-alert {
  padding: 0.2em;
  border: 1px solid #778899;
  border-bottom: none;
  height: 16px;
}

.add-new-content-listing {
  border: 1px solid #778899;
  background: #CFDBE7;
  color: #444444;
  margin: 0 0 1em;
}

.add-new-content-listing p {
  padding: 0.2em;
}

.new-content-listing a {
  font-weight: bold;
}

.new-content-listing img {
  float: left;
  padding-right: 0.4em;
}

/* table less styling like tables */

h2.top {
  margin: 0;
  padding: 0 0.3em 0.3em;
  color: #c5d4ca;
  background-color: #456;
}

h2.top img {
  float: left;
  padding-top: 0.2em;
  padding-right: 0.4em;
}

h3.top-controls {
  padding: 0 0.3em 0.2em;
  background-color: #567;
  margin: 0 0 0.1em;
  color: #ddeee3;
  line-height: 100%;
}

/* loading message */
div#remote-request-loading {
  display:none;
  position: absolute;
  top: 0px;
  right: 0px;
  color: #3c2d50;
  padding: 0.1em 1.5em;
  border-left: 1px solid black;
  border-bottom: 1px solid black;
  background-color: #f7d1d1;
  z-index: 2000;
}

/* _______ simple-page layout selectors _______ */

div.simple-page {
  padding: 50px;
  color: black;
  border-bottom: 1em solid #4C5C6C;
}
div.simple-page div.pathbar {
  border-bottom: 1px solid #aaa;
}
div.simple-page h1 { font-size: 170%;}
div.simple-page div.notification {
  position: relative;
  top: 16px;
  width: 50em;
  margin: 2.5em auto 5em;
  padding: 20px;
  border-bottom: 1px solid #aaa;
  -moz-box-shadow: 0px 0px 15px white;
  -webkit-box-shadow: 0px 0px 15px white;
  box-shadow: 0px 0px 15px white;
}
div.simple-page  div.notification h1 {
  margin: 0 0 0.5em;
}
div.simple-page div.notification p {
  margin: 0.5em 0;
}
div.simple-page div.notification li {
  list-style: disc outside none;
}
div.simple-page div.notification a:link,
div.simple-page div.notification a:visited {
  color: blue;
}
div.simple-page div.notification div.controls {
  height: 2em;
  margin-top: 1em;
  padding: 1em 0 0;
  border-top: 1px solid #555;
}
